==> ooo_dev_tools-0.9.0.tar.gz: ooo_dev_tools-0.9.0/ooodev/format/writer/modify/frame/type/__init__.py <==
from ooodev.format.inner.direct.write.frame.frame_type.anchor import AnchorKind as AnchorKind
from ooodev.format.inner.direct.write.frame.frame_type.position import HoriOrient as HoriOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import Horizontal as Horizontal
from ooodev.format.inner.direct.write.frame.frame_type.position import RelHoriOrient as RelHoriOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import RelVertOrient as RelVertOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import Vertical as Vertical
from ooodev.format.inner.direct.write.frame.frame_type.position import VertOrient as VertOrient
from ooodev.format.inner.direct.write.image.image_type.size import AbsoluteSize as AbsoluteSize
from ooodev.format.inner.direct.write.image.image_type.size import RelativeKind as RelativeKind
from ooodev.format.inner.direct.write.image.image_type.size import RelativeSize as RelativeSize
from ooodev.format.inner.modify.write.frame.frame_type.anchor import Anchor as Anchor
from ooodev.format.inner.modify.write.frame.frame_type.anchor import InnerAnchor as InnerAnchor
from ooodev.format.inner.modify.write.frame.frame_type.position import InnerPosition as InnerPosition
from ooodev.format.inner.modify.write.frame.frame_type.position import Position as Position
from ooodev.format.inner.modify.write.frame.frame_type.size import InnerSize as InnerSize
from ooodev.format.inner.modify.write.frame.frame_type.size import Size as Size
from ooodev.format.writer.style.frame.style_frame_kind import StyleFrameKind as StyleFrameKind

__all__ = [
    "AnchorKind",
    "HoriOrient",
    "Horizontal",
    "RelHoriOrient",
    "RelVertOrient",
    "Vertical",
    "VertOrient",
    "AbsoluteSize",
    "RelativeKind",
    "RelativeSize",
    "Anchor",
    "InnerAnchor",
    "InnerPosition",
    "Position",
    "InnerSize",
    "Size",
]

==> ooo_dev_tools-0.42.1.tar.gz: ooo_dev_tools-0.42.1/ooodev/format/writer/modify/frame/type/__init__.py <==
from ooodev.format.inner.direct.write.frame.frame_type.anchor import AnchorKind as AnchorKind
from ooodev.format.inner.direct.write.frame.frame_type.position import HoriOrient as HoriOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import Horizontal as Horizontal
from ooodev.format.inner.direct.write.frame.frame_type.position import RelHoriOrient as RelHoriOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import RelVertOrient as RelVertOrient
from ooodev.format.inner.direct.write.frame.frame_type.position import Vertical as Vertical
from ooodev.format.inner.direct.write.frame.frame_type.position import VertOrient as VertOrient
from ooodev.format.inner.direct.write.image.image_type.size import AbsoluteSize as AbsoluteSize
from ooodev.format.inner.direct.write.image.image_type.size import RelativeKind as RelativeKind
from ooodev.format.inner.direct.write.image.image_type.size import RelativeSize as RelativeSize
from ooodev.format.inner.modify.write.frame.frame_type.anchor import Anchor as Anchor
from ooodev.format.inner.direct.write.frame.frame_type.anchor import Anchor as InnerAnchor
from ooodev.format.inner.direct.write.frame.frame_type.position import Position as InnerPosition
from ooodev.format.inner.modify.write.frame.frame_type.position import Position as Position
from ooodev.format.inner.direct.write.frame.frame_type.size import Size as InnerSize
from ooodev.format.inner.modify.write.frame.frame_type.size import Size as Size
from ooodev.format.writer.style.frame.style_frame_kind import StyleFrameKind as StyleFrameKind

__all__ = ["Anchor", "Position", "Size"]
